@@ -1,5 +1,3 @@
-#!/usr/bin/python
-#
 # Copyright 2007 Google Inc.
 #
 # This program is free software; you can redistribute it and/or
@@ -21,6 +19,7 @@
 __author__ = ('jaq@google.com (Jamie Wilkinson)',
               'vasilios@google.com (Vasilios Hoffman)')
 
+import calendar
 import logging
 import time
 import ldap
@@ -85,6 +84,8 @@ class LdapSource(source.Source):
                       retry_delay=conf['retry_delay'])
       if conf['tls_starttls'] == 1:
           self.conn.start_tls_s()
+      if 'ldap_debug' in conf:
+        self.conn.set_option(ldap.OPT_DEBUG_LEVEL, conf['ldap_debug'])
     else:
       self.conn = conn
 
@@ -392,7 +393,7 @@ class LdapSource(source.Source):
     """Verify that this source is contactable and can be queried for data."""
     if since is None:
       # one minute in the future
-      since = time.gmtime(time.time() + 60)
+      since = int(time.time() + 60)
     results = self.GetPasswdMap(since=since)
     return len(results)
 
@@ -407,21 +408,21 @@ class UpdateGetter(object):
       ldap_ts_string: An LDAP timestamp string in the format %Y%m%d%H%M%SZ
 
     Returns:
-      a time.struct_time
+      number of seconds since epoch.
     """
     t = time.strptime(ldap_ts_string, '%Y%m%d%H%M%SZ')
-    return t
+    return int(calendar.timegm(t))
 
   def FromTimestampToLdap(self, ts):
     """Transforms nss_cache internal timestamp into a LDAP timestamp.
 
     Args:
-      ts: a time.struct_time
+      ts: number of seconds since epoch
 
     Returns:
       LDAP format timestamp string.
     """
-    t = time.strftime('%Y%m%d%H%M%SZ', ts)
+    t = time.strftime('%Y%m%d%H%M%SZ', time.gmtime(ts))
     return t
 
   def GetUpdates(self, source, search_base, search_filter,
@@ -532,7 +533,7 @@ class PasswdUpdateGetter(UpdateGetter):
     pw.dir = obj['homeDirectory'][0]
 
     # hack
-    pw.passwd = 'x'
+    pw.passwd = '*'
 
     return pw
 
