@@ -1,5 +1,3 @@
-#!/usr/bin/python
-#
 # Copyright 2007 Google Inc.
 #
 # This program is free software; you can redistribute it and/or
@@ -106,6 +104,21 @@ class TestLdapSource(mox.MoxTestBase):
     self.assertEquals(source.conf['tls_cacertfile'],
                       'TEST_TLS_CACERTFILE')
 
+  def testDebugLevelSet(self):
+    config = dict(self.config)
+    config['ldap_debug'] = 3
+    mock_rlo = self.mox.CreateMock(ldap.ldapobject.ReconnectLDAPObject)
+    mock_rlo.set_option(ldap.OPT_DEBUG_LEVEL, 3)
+    mock_rlo.simple_bind_s(cred='TEST_BIND_PASSWORD', who='TEST_BIND_DN')
+    self.mox.StubOutWithMock(ldap, 'ldapobject')
+    ldap.ldapobject.ReconnectLDAPObject(
+        retry_max='TEST_RETRY_MAX',
+        retry_delay='TEST_RETRY_DELAY',
+        uri='TEST_URI').AndReturn(mock_rlo)
+    
+    self.mox.ReplayAll()
+    source = ldapsource.LdapSource(config)
+
   def testTrapServerDownAndRetry(self):
     config = dict(self.config)
     config['bind_dn'] = ''
@@ -624,7 +637,7 @@ class TestLdapSource(mox.MoxTestBase):
 
     self.mox.ReplayAll()
     source = ldapsource.LdapSource(self.config)
-    self.assertEquals(0, source.Verify(time.gmtime(0)))
+    self.assertEquals(0, source.Verify(0))
 
 
 class TestUpdateGetter(unittest.TestCase):
@@ -644,6 +657,18 @@ class TestUpdateGetter(unittest.TestCase):
 
     self.source = DummySource()
 
+  def testFromTimestampToLdap(self):
+    ts = 1259641025
+    expected_ldap_ts = '20091201041705Z'
+    self.assertEquals(expected_ldap_ts,
+                      ldapsource.UpdateGetter().FromTimestampToLdap(ts))
+
+  def testFromLdapToTimestamp(self):
+    expected_ts = 1259641025
+    ldap_ts = '20091201041705Z'
+    self.assertEquals(expected_ts,
+                      ldapsource.UpdateGetter().FromLdapToTimestamp(ldap_ts))
+
   def testPasswdEmptySourceGetUpdates(self):
     """Test that getUpdates on the PasswdUpdateGetter works."""
     getter = ldapsource.PasswdUpdateGetter()
